@@ -47,6 +47,9 @@ ScreenLockerKcmForm::ScreenLockerKcmForm(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
+    kcfg_Timeout->setSuffix(ki18ncp("Spinbox suffix. Short for minutes"," min"," mins"));
+
+    kcfg_LockGrace->setSuffix(ki18ncp("Spinbox suffix. Short for seconds"," sec"," secs"));
 }
 
 
